.. _pydl.goddard:

==================================
Goddard Utilities (`pydl.goddard`)
==================================

Introduction
++++++++++++

This is a placeholder for Goddard Utilities documentation.

API
+++

.. automodapi:: pydl.goddard
   :no-inheritance-diagram:

.. automodapi:: pydl.goddard.astro
    :no-inheritance-diagram:

.. automodapi:: pydl.goddard.math
    :no-inheritance-diagram:

.. automodapi:: pydl.goddard.misc
    :no-inheritance-diagram:
